aboutsummaryrefslogtreecommitdiffstats
path: root/vid-app-common/src/main/java/org/onap/vid/job/JobCommand.java
diff options
context:
space:
mode:
Diffstat (limited to 'vid-app-common/src/main/java/org/onap/vid/job/JobCommand.java')
-rw-r--r--vid-app-common/src/main/java/org/onap/vid/job/JobCommand.java9
1 files changed, 5 insertions, 4 deletions
diff --git a/vid-app-common/src/main/java/org/onap/vid/job/JobCommand.java b/vid-app-common/src/main/java/org/onap/vid/job/JobCommand.java
index c32645cad..7f62bcac6 100644
--- a/vid-app-common/src/main/java/org/onap/vid/job/JobCommand.java
+++ b/vid-app-common/src/main/java/org/onap/vid/job/JobCommand.java
@@ -1,7 +1,8 @@
package org.onap.vid.job;
+import org.onap.vid.job.impl.JobSharedData;
+
import java.util.Map;
-import java.util.UUID;
/**
@@ -13,11 +14,11 @@ public interface JobCommand {
/**
* Initialize the command state
* @param jobUuid Parent job's uuid
* @param data An input to be set into the command. Each implementation may expect different keys in the map.
* @return Returns itself
*/
- default JobCommand init(UUID jobUuid, Map<String, Object> data) {
+ default JobCommand init(JobSharedData sharedData, Map<String, Object> commandData) {
return this;
}
@@ -13,11 +14,11 @@ public interface JobCommand {
/**
* Initialize the command state
- * @param jobUuid Parent job's uuid
- * @param data An input to be set into the command. Each implementation may expect different keys in the map.
+ * @param sharedData shared data cross all job commands
+ * @param commandData An input to be set into the command. Each implementation may expect different keys in the map.
* @return Returns itself
*/